package me.lensfrex.trailblazer.api.v1.controllers.auth.login;

import com.google.gson.Gson;
import com.google.gson.JsonParseException;
import me.lensfrex.trailblazer.api.v1.beans.requests.LoginRequestBody;
import me.lensfrex.trailblazer.api.v1.beans.responses.general.ResponseBase;
import me.lensfrex.trailblazer.api.v1.beans.responses.general.ResponseCode;
import me.lensfrex.trailblazer.api.v1.exceptions.RequestDataInvalidException;
import me.lensfrex.trailblazer.api.v1.exceptions.user.LoginInfoWrongException;
import me.lensfrex.trailblazer.api.v1.service.auth.login.LoginService;
import me.lensfrex.trailblazer.api.v1.utils.InputChecker;
import me.lensfrex.trailblazer.api.v1.utils.jwt.JWTManager;
import org.mindrot.jbcrypt.BCrypt;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@RestController
@RequestMapping("/user")
public class Login {
    private static final Gson gson = new Gson();
    private static final JWTManager jwtManager = JWTManager.getInstance();

    @Resource
    private LoginService loginService;

    @PostMapping(value = "/login", produces = "application/json")
    public String login(@RequestBody String request) {
        LoginRequestBody loginRequestBody;
        try {
            loginRequestBody = gson.fromJson(request, LoginRequestBody.class);
            if (InputChecker.hasInvalidChar(loginRequestBody.getUserName()) ||
                    InputChecker.hasInvisibleChar(loginRequestBody.getPassword())) {
                throw new RequestDataInvalidException();
            }

            return gson.toJson(loginService.getLoginResponseBody(loginRequestBody));
        } catch (JsonParseException | RequestDataInvalidException e) {
            return gson.toJson(ResponseBase.error(ResponseCode.REQUEST_FORMAT_INVALID, "请求的数据格式不对"));
        } catch (LoginInfoWrongException e) {
            return gson.toJson(ResponseBase.error(ResponseCode.PASSWORD_WRONG, "用户名或密码错误"));
        } catch (Exception e) {
            return gson.toJson(ResponseBase.error(ResponseCode.SERVER_ERROR, "服务器内部错误，请联系那个背锅的家伙"));
        }
    }

    public boolean identifyPassword(String originPassword, String bcryptPassword) {
        return BCrypt.checkpw(originPassword, bcryptPassword);
    }
}