package me.lensfrex.trailblazer.api.v1.service.auth.login;

import me.lensfrex.trailblazer.api.v1.beans.requests.LoginRequestBody;
import me.lensfrex.trailblazer.api.v1.beans.responses.LoginResponseData;
import me.lensfrex.trailblazer.api.v1.beans.responses.general.ResponseBase;
import me.lensfrex.trailblazer.api.v1.dao.UserDao;
import me.lensfrex.trailblazer.api.v1.exceptions.user.LoginInfoWrongException;
import me.lensfrex.trailblazer.api.v1.pojos.UserInformation;
import me.lensfrex.trailblazer.api.v1.utils.jwt.JWTManager;
import org.mindrot.jbcrypt.BCrypt;
import org.springframework.stereotype.Service;

import java.time.Instant;
import java.time.temporal.ChronoUnit;
import java.util.Date;

@Service
public class LoginService {
    private static final JWTManager jwtManager = JWTManager.getInstance();

    public ResponseBase<LoginResponseData> getLoginResponseBody(LoginRequestBody loginRequestBody) throws LoginInfoWrongException {
        UserInformation userDatabaseInformation = UserDao.getUser(loginRequestBody.getUserName());

        if (userDatabaseInformation == null) {
            throw new LoginInfoWrongException();
        }

        if (!identifyPassword(loginRequestBody.getPassword(), userDatabaseInformation.password)) {
            throw new LoginInfoWrongException();
        }

        Date expireDate = Date.from(Instant.now().plus(JWTManager.TOKEN_DEFAULT_EXPIRE_DAY, ChronoUnit.DAYS));
        String userToken = jwtManager.createNewJWT(loginRequestBody.getUserName(), expireDate);

        LoginResponseData loginResponseData = new LoginResponseData(
                userDatabaseInformation.uid,
                userDatabaseInformation.uuid,
                userDatabaseInformation.accountStatus,
                userToken,
                expireDate.getTime());

        return ResponseBase.success(loginResponseData);
    }

    private boolean identifyPassword(String originPassword, String bcryptPassword) {
        return BCrypt.checkpw(originPassword, bcryptPassword);
    }
}